==> blancoMessage-0.4.0-src.zip: blancoMessage/blanco.php/main/blanco/message/message/BlancoMessageMessage.php <==
<?php
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
/*. DOC <@package blanco.message.message;>.*/

/*. require_module 'standard'; .*/;

/**
 * blancoMessageIɗp郁bZ[WNXłB
 */
class BlancoMessageMessage {
    /**
     * [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]
     *
     * No.2:
     */
    const MBMSGI01 = '[MBMSGI01] bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B';

    /**
     * [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]
     *
     * No.3:
     */
    const MBMSGI02 = '[MBMSGI02] T|[gȂo̓vO~Oꏈn[{0}]w肳܂B';

    /**
     * [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]
     *
     * No.4:
     */
    const MBMSGI03 = '[MBMSGI03] bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B';

    /**
     * [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]
     *
     * No.5:
     */
    const MBMSGI04 = '[MBMSGI04] bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB';

    /**
     * [^fBNg[{0}]݂܂B]
     *
     * No.8:
     */
    const MBMSGA01 = '[MBMSGA01] ^fBNg[{0}]݂܂B';

    /**
     * bZ[W`ID[BlancoMessage]AL[[MBMSGI01]̕擾܂B
     *
     * No.2:
     * [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]
     *
     * @param string $arg0 u{0}̒lB
     * @return string bZ[WB
     */
    public /*.string.*/ function getMbmsgi01(/*.string.*/ $arg0) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 1) {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi01 ̃p[^[1]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($arg0) !== 'string' && gettype($arg0) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi01 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg0) . ']^^܂B');
        }

        if ($arg0 === null) {
            throw new Exception('\bh[getMbmsgi01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }

        return '[MBMSGI01] bZ[W`ID[' . $arg0 . ']̃pbP[Ww肳Ă܂B';
    }

    /**
     * bZ[W`ID[BlancoMessage]AL[[MBMSGI02]̕擾܂B
     *
     * No.3:
     * [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]
     *
     * @param string $arg0 u{0}̒lB
     * @return string bZ[WB
     */
    public /*.string.*/ function getMbmsgi02(/*.string.*/ $arg0) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 1) {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi02 ̃p[^[1]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($arg0) !== 'string' && gettype($arg0) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi02 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg0) . ']^^܂B');
        }

        if ($arg0 === null) {
            throw new Exception('\bh[getMbmsgi02]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }

        return '[MBMSGI02] T|[gȂo̓vO~Oꏈn[' . $arg0 . ']w肳܂B';
    }

    /**
     * bZ[W`ID[BlancoMessage]AL[[MBMSGI03]̕擾܂B
     *
     * No.4:
     * [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]
     *
     * @param string $arg0 u{0}̒lB
     * @param string $arg1 u{1}̒lB
     * @return string bZ[WB
     */
    public /*.string.*/ function getMbmsgi03(/*.string.*/ $arg0, /*.string.*/ $arg1) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 2) {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi03 ̃p[^[2]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($arg0) !== 'string' && gettype($arg0) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi03 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg0) . ']^^܂B');
        }
        if (gettype($arg1) !== 'string' && gettype($arg1) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi03 2Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg1) . ']^^܂B');
        }

        if ($arg0 === null) {
            throw new Exception('\bh[getMbmsgi03]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }
        if ($arg1 === null) {
            throw new Exception('\bh[getMbmsgi03]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }

        return '[MBMSGI03] bZ[W`ID[' . $arg0 . ']ɂāAL[[' . $arg1 . ']2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B';
    }

    /**
     * bZ[W`ID[BlancoMessage]AL[[MBMSGI04]̕擾܂B
     *
     * No.5:
     * [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]
     *
     * @param string $arg0 u{0}̒lB
     * @param string $arg1 u{1}̒lB
     * @param string $arg2 u{2}̒lB
     * @param string $arg3 u{3}̒lB
     * @return string bZ[WB
     */
    public /*.string.*/ function getMbmsgi04(/*.string.*/ $arg0, /*.string.*/ $arg1, /*.string.*/ $arg2, /*.string.*/ $arg3) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 4) {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi04 ̃p[^[4]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($arg0) !== 'string' && gettype($arg0) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi04 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg0) . ']^^܂B');
        }
        if (gettype($arg1) !== 'string' && gettype($arg1) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi04 2Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg1) . ']^^܂B');
        }
        if (gettype($arg2) !== 'string' && gettype($arg2) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi04 3Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg2) . ']^^܂B');
        }
        if (gettype($arg3) !== 'string' && gettype($arg3) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi04 4Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg3) . ']^^܂B');
        }

        if ($arg0 === null) {
            throw new Exception('\bh[getMbmsgi04]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }
        if ($arg1 === null) {
            throw new Exception('\bh[getMbmsgi04]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }
        if ($arg2 === null) {
            throw new Exception('\bh[getMbmsgi04]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }
        if ($arg3 === null) {
            throw new Exception('\bh[getMbmsgi04]̃p[^[arg3]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }

        return '[MBMSGI04] bZ[W`ID[' . $arg0 . ']ɂāAL[[' . $arg1 . ']̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[' . $arg2 . ']ƃ\[XohƂĔfꍇ̒ǔ[' . $arg3 . ']ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB';
    }

    /**
     * bZ[W`ID[BlancoMessage]AL[[MBMSGA01]̕擾܂B
     *
     * No.8:
     * [^fBNg[{0}]݂܂B]
     *
     * @param string $arg0 u{0}̒lB
     * @return string bZ[WB
     */
    public /*.string.*/ function getMbmsga01(/*.string.*/ $arg0) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 1) {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsga01 ̃p[^[1]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($arg0) !== 'string' && gettype($arg0) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsga01 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg0) . ']^^܂B');
        }

        if ($arg0 === null) {
            throw new Exception('\bh[getMbmsga01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }

        return '[MBMSGA01] ^fBNg[' . $arg0 . ']݂܂B';
    }
}
?>

==> blancoMessage-0.6.3-src.zip: blancoMessage/blanco.php/main/blanco/message/message/BlancoMessageMessage.php <==
<?php
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
/*. DOC <@package blanco.message.message;>.*/

/*. require_module 'standard'; .*/;

/**
 * blancoMessageIɗp郁bZ[WNXłB
 */
class BlancoMessageMessage {
    /**
     * [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]
     *
     * No.2:
     */
    const MBMSGI01 = '[MBMSGI01] bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B';

    /**
     * L[l: KEY_MBMSGI01
     *
     * No.2:
     */
    const KEY_MBMSGI01 = 'MBMSGI01';

    /**
     * [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]
     *
     * No.3:
     */
    const MBMSGI02 = '[MBMSGI02] T|[gȂo̓vO~Oꏈn[{0}]w肳܂B';

    /**
     * L[l: KEY_MBMSGI02
     *
     * No.3:
     */
    const KEY_MBMSGI02 = 'MBMSGI02';

    /**
     * [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]
     *
     * No.4:
     */
    const MBMSGI03 = '[MBMSGI03] bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B';

    /**
     * L[l: KEY_MBMSGI03
     *
     * No.4:
     */
    const KEY_MBMSGI03 = 'MBMSGI03';

    /**
     * [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]
     *
     * No.5:
     */
    const MBMSGI04 = '[MBMSGI04] bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB';

    /**
     * L[l: KEY_MBMSGI04
     *
     * No.5:
     */
    const KEY_MBMSGI04 = 'MBMSGI04';

    /**
     * [^fBNg[{0}]݂܂B]
     *
     * No.8:
     */
    const MBMSGA01 = '[MBMSGA01] ^fBNg[{0}]݂܂B';

    /**
     * L[l: KEY_MBMSGA01
     *
     * No.8:
     */
    const KEY_MBMSGA01 = 'MBMSGA01';

    /**
     * bZ[W`ID[BlancoMessage]AL[[MBMSGI01]̕擾܂B
     *
     * No.2:
     * [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]
     *
     * @param string $arg0 u{0}̒lB
     * @return string bZ[WB
     */
    public /*.string.*/ function getMbmsgi01(/*.string.*/ $arg0) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 1) {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi01 ̃p[^[1]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($arg0) !== 'string' && gettype($arg0) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi01 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg0) . ']^^܂B');
        }

        if ($arg0 === null) {
            throw new Exception('\bh[getMbmsgi01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }

        return '[MBMSGI01] bZ[W`ID[' . $arg0 . ']̃pbP[Ww肳Ă܂B';
    }

    /**
     * bZ[W`ID[BlancoMessage]AL[[MBMSGI02]̕擾܂B
     *
     * No.3:
     * [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]
     *
     * @param string $arg0 u{0}̒lB
     * @return string bZ[WB
     */
    public /*.string.*/ function getMbmsgi02(/*.string.*/ $arg0) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 1) {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi02 ̃p[^[1]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($arg0) !== 'string' && gettype($arg0) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi02 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg0) . ']^^܂B');
        }

        if ($arg0 === null) {
            throw new Exception('\bh[getMbmsgi02]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }

        return '[MBMSGI02] T|[gȂo̓vO~Oꏈn[' . $arg0 . ']w肳܂B';
    }

    /**
     * bZ[W`ID[BlancoMessage]AL[[MBMSGI03]̕擾܂B
     *
     * No.4:
     * [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]
     *
     * @param string $arg0 u{0}̒lB
     * @param string $arg1 u{1}̒lB
     * @return string bZ[WB
     */
    public /*.string.*/ function getMbmsgi03(/*.string.*/ $arg0, /*.string.*/ $arg1) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 2) {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi03 ̃p[^[2]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($arg0) !== 'string' && gettype($arg0) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi03 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg0) . ']^^܂B');
        }
        if (gettype($arg1) !== 'string' && gettype($arg1) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi03 2Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg1) . ']^^܂B');
        }

        if ($arg0 === null) {
            throw new Exception('\bh[getMbmsgi03]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }
        if ($arg1 === null) {
            throw new Exception('\bh[getMbmsgi03]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }

        return '[MBMSGI03] bZ[W`ID[' . $arg0 . ']ɂāAL[[' . $arg1 . ']2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B';
    }

    /**
     * bZ[W`ID[BlancoMessage]AL[[MBMSGI04]̕擾܂B
     *
     * No.5:
     * [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]
     *
     * @param string $arg0 u{0}̒lB
     * @param string $arg1 u{1}̒lB
     * @param string $arg2 u{2}̒lB
     * @param string $arg3 u{3}̒lB
     * @return string bZ[WB
     */
    public /*.string.*/ function getMbmsgi04(/*.string.*/ $arg0, /*.string.*/ $arg1, /*.string.*/ $arg2, /*.string.*/ $arg3) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 4) {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi04 ̃p[^[4]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($arg0) !== 'string' && gettype($arg0) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi04 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg0) . ']^^܂B');
        }
        if (gettype($arg1) !== 'string' && gettype($arg1) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi04 2Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg1) . ']^^܂B');
        }
        if (gettype($arg2) !== 'string' && gettype($arg2) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi04 3Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg2) . ']^^܂B');
        }
        if (gettype($arg3) !== 'string' && gettype($arg3) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsgi04 4Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg3) . ']^^܂B');
        }

        if ($arg0 === null) {
            throw new Exception('\bh[getMbmsgi04]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }
        if ($arg1 === null) {
            throw new Exception('\bh[getMbmsgi04]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }
        if ($arg2 === null) {
            throw new Exception('\bh[getMbmsgi04]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }
        if ($arg3 === null) {
            throw new Exception('\bh[getMbmsgi04]̃p[^[arg3]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }

        return '[MBMSGI04] bZ[W`ID[' . $arg0 . ']ɂāAL[[' . $arg1 . ']̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[' . $arg2 . ']ƃ\[XohƂĔfꍇ̒ǔ[' . $arg3 . ']ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB';
    }

    /**
     * bZ[W`ID[BlancoMessage]AL[[MBMSGA01]̕擾܂B
     *
     * No.8:
     * [^fBNg[{0}]݂܂B]
     *
     * @param string $arg0 u{0}̒lB
     * @return string bZ[WB
     */
    public /*.string.*/ function getMbmsga01(/*.string.*/ $arg0) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 1) {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsga01 ̃p[^[1]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($arg0) !== 'string' && gettype($arg0) !== 'NULL') {
            throw new Exception('[ArgumentException]: BlancoMessageMessage.getMbmsga01 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($arg0) . ']^^܂B');
        }

        if ($arg0 === null) {
            throw new Exception('\bh[getMbmsga01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B');
        }

        return '[MBMSGA01] ^fBNg[' . $arg0 . ']݂܂B';
    }
}
?>
